@@ -3,6 +3,8 @@ Test the EventsRouter
 """
 from unittest.mock import MagicMock, call, patch, sentinel
 
+import ddt
+from django.conf import settings
 from django.test import TestCase
 from edx_django_utils.cache.utils import TieredCache
 from eventtracking.processors.exceptions import EventEmissionExit
@@ -10,6 +12,7 @@ from tincan.statement import Statement
 
 from event_routing_backends.backends.events_router import EventsRouter
 from event_routing_backends.helpers import get_business_critical_events
+from event_routing_backends.models import RouterConfiguration
 from event_routing_backends.processors.transformer_utils.exceptions import EventNotDispatched
 from event_routing_backends.tests.factories import RouterConfigurationFactory
 from event_routing_backends.utils.http_client import HttpClient
@@ -17,105 +20,37 @@ from event_routing_backends.utils.xapi_lrs_client import LrsClient
 
 ROUTER_CONFIG_FIXTURE = [
     {
-        'router_type': 'AUTH_HEADERS',
+        'headers': {},
         'match_params': {
             'data.key': 'value'
         },
-        'host_configurations': {
-            'url': 'http://test1.com',
-            'headers': {},
-            'auth_scheme': 'Bearer',
-            'auth_key': 'test_key'
-        },
         'override_args': {
             'new_key': 'new_value'
         }
     },
     {
-        'router_type': 'AUTH_HEADERS',
         'match_params': {
-            'data.key': 'value'
-        },
-        'host_configurations': {
-            'url': 'http://test1.com',
-            'headers': {},
+            'data.key': 'value1'
         },
         'override_args': {
             'new_key': 'new_value'
         }
     },
     {
-        'router_type': 'OAUTH2',
-        'match_params': {
-            'non_existing.id.value': 'test'
-        },
-        'host_configurations': {
-            'url': 'http://test2.com',
-            'client_id': 'id',
-            'client_secret': 'secret'
-        },
-        'override_args': {}
-    },
-    {
-        'router_type': 'API_KEY',
         'match_params': {
             'data.key': 'value'
-        },
-        'host_configurations': {
-            'url': 'http://test3.com',
-            'api_key': 'test_key'
         }
     },
     {
-        'router_type': 'XAPI_LRS',
         'match_params': {},
         'host_configurations': {
-            'url': 'http://test3.com',
-            'version': '1.0.1'
-        }
-    },
-    {
-        'router_type': 'XAPI_LRS',
-        'match_params': {},
-        'host_configurations': {
-            'url': 'http://test3.com',
             'version': '1.0.1',
-            'auth_scheme': 'bearer',
-            'auth_key': 'key',
-        }
-    },
-    {
-        'router_type': 'XAPI_LRS',
-        'match_params': {},
-        'host_configurations': {
-            'url': 'http://test3.com',
-            'version': '1.0.1',
-            'auth_scheme': 'bearer',
-            'username': 'abc',
-            'password': 'xyz'
-        }
-    },
-    {
-        'router_type': 'AUTH_HEADERS',
-        'match_params': {
-            'data.key': 'value'
-        },
-        'host_configurations': {
-            'url': 'http://test1.com',
-            'headers': {},
-            'username': 'abc',
-            'password': 'xyz'
-        },
-        'override_args': {
-            'new_key': 'new_value'
         }
     }
 ]
 
-# Maximum number of retries before giving up
-MAX_RETRIES = 3
-
 
+@ddt.ddt
 class TestEventsRouter(TestCase):
     """
     Test the EventsRouter
@@ -167,7 +102,7 @@ class TestEventsRouter(TestCase):
         mocked_post.assert_not_called()
 
         self.assertIn(call(
-            'Could not process event %s for backend %s\'s router',
+            'Could not process edx event "%s" for backend %s\'s router',
             self.transformed_event['name'],
             'test',
             exc_info=True
@@ -180,19 +115,22 @@ class TestEventsRouter(TestCase):
     @patch('event_routing_backends.tasks.logger')
     def test_generic_exception_business_critical_event(self, mocked_logger, mocked_post):
         RouterConfigurationFactory.create(
-            backend_name='test_backend',
+            backend_name=RouterConfiguration.XAPI_BACKEND,
             enabled=True,
             route_url='http://test3.com',
-            configurations=ROUTER_CONFIG_FIXTURE[0:1]
+            auth_scheme=RouterConfiguration.AUTH_BEARER,
+            auth_key='test_key',
+            configurations=ROUTER_CONFIG_FIXTURE[0]
         )
 
-        router = EventsRouter(processors=[], backend_name='test_backend')
+        router = EventsRouter(processors=[], backend_name=RouterConfiguration.CALIPER_BACKEND)
         event_data = self.transformed_event.copy()
         business_critical_events = get_business_critical_events()
         event_data['name'] = business_critical_events[0]
         router.send(event_data)
 
-        self.assertEqual(mocked_logger.exception.call_count, MAX_RETRIES + 1)
+        self.assertEqual(mocked_logger.exception.call_count,
+                         getattr(settings, 'EVENT_ROUTING_BACKEND_COUNTDOWN', 3) + 1)
         mocked_post.assert_not_called()
 
     @patch('event_routing_backends.utils.http_client.requests.post')
@@ -204,21 +142,20 @@ class TestEventsRouter(TestCase):
         mocked_post.assert_not_called()
 
         self.assertIn(
-            call('Could not find an enabled router configurations for backend %s', 'test'),
+            call('Could not find any enabled router configuration for backend %s', 'test'),
             mocked_logger.error.mock_calls
         )
 
     @patch('event_routing_backends.utils.http_client.requests.post')
     @patch('event_routing_backends.tasks.logger')
     def test_with_unsupported_routing_strategy(self, mocked_logger, mocked_post):
-        configurations = ROUTER_CONFIG_FIXTURE[0:1].copy()
-        configurations[0]['router_type'] = 'INVALID_TYPE'
-
         RouterConfigurationFactory.create(
             backend_name='test_backend',
             enabled=True,
             route_url='http://test3.com',
-            configurations=configurations
+            auth_scheme=RouterConfiguration.AUTH_BEARER,
+            auth_key='test_key',
+            configurations=ROUTER_CONFIG_FIXTURE[0]
         )
 
         router = EventsRouter(processors=[], backend_name='test_backend')
@@ -235,7 +172,7 @@ class TestEventsRouter(TestCase):
             backend_name='test_backend',
             enabled=True,
             route_url='http://test3.com',
-            configurations=ROUTER_CONFIG_FIXTURE[1:1]
+            configurations=ROUTER_CONFIG_FIXTURE[1]
         )
 
         router = EventsRouter(processors=[], backend_name='test_backend')
@@ -252,63 +189,114 @@ class TestEventsRouter(TestCase):
             mocked_logger.info.mock_calls
         )
 
-    @patch('event_routing_backends.utils.http_client.requests.post')
-    def test_with_multiple_router_config(self, mocked_post):
-        RouterConfigurationFactory.create(
-            backend_name='test_backend',
-            enabled=True,
-            route_url='http://test3.com',
-            configurations=ROUTER_CONFIG_FIXTURE[1:1]
+    @ddt.data(
+        (
+            RouterConfiguration.XAPI_BACKEND,
+        ),
+        (
+            RouterConfiguration.CALIPER_BACKEND,
         )
-        RouterConfigurationFactory.create(
-            backend_name='test_backend',
-            enabled=True,
-            route_url='http://test1.com',
-            configurations=ROUTER_CONFIG_FIXTURE[1:2]
-        )
-
-        router = EventsRouter(processors=[], backend_name='test_backend')
-        TieredCache.dangerous_clear_all_tiers()
-        router.send(self.transformed_event)
-        self.assertEqual(mocked_post.call_count, 1)
-
+    )
     @patch.dict('event_routing_backends.tasks.ROUTER_STRATEGY_MAPPING', {
         'AUTH_HEADERS': MagicMock(side_effect=EventNotDispatched)
     })
     @patch('event_routing_backends.utils.http_client.requests.post')
     @patch('event_routing_backends.tasks.logger')
-    def test_generic_exception(self, mocked_logger, mocked_post):
+    @ddt.unpack
+    def test_generic_exception(self, backend_name, mocked_logger, mocked_post):
         RouterConfigurationFactory.create(
-            backend_name='test_backend',
+            backend_name=backend_name,
             enabled=True,
             route_url='http://test3.com',
-            configurations=ROUTER_CONFIG_FIXTURE[0:1]
+            configurations=ROUTER_CONFIG_FIXTURE[2]
         )
 
-        router = EventsRouter(processors=[], backend_name='test_backend')
+        router = EventsRouter(processors=[], backend_name=backend_name)
         router.send(self.transformed_event)
-
-        self.assertEqual(mocked_logger.exception.call_count, MAX_RETRIES + 1)
-        mocked_post.assert_not_called()
+        if backend_name == RouterConfiguration.CALIPER_BACKEND:
+            self.assertEqual(mocked_logger.exception.call_count,
+                             getattr(settings, 'EVENT_ROUTING_BACKEND_COUNTDOWN', 3) + 1)
+            mocked_post.assert_not_called()
+        else:
+            mocked_logger.exception.assert_not_called()
 
     def test_with_non_dict_event(self):
         RouterConfigurationFactory.create(
-            backend_name='test_routing',
+            backend_name=RouterConfiguration.XAPI_BACKEND,
             enabled=True,
             route_url='http://test3.com',
-            configurations=ROUTER_CONFIG_FIXTURE[4:5]
+            configurations=ROUTER_CONFIG_FIXTURE[3]
         )
-        router = EventsRouter(processors=[], backend_name='test_routing')
+        router = EventsRouter(processors=[], backend_name=RouterConfiguration.XAPI_BACKEND)
         transformed_event = Statement()
         with self.assertRaises(ValueError):
             router.send(transformed_event)
 
+    @ddt.data(
+        (RouterConfiguration.AUTH_BASIC,
+         None,
+         'abc',
+         'xyz',
+         RouterConfiguration.CALIPER_BACKEND,
+         'http://test1.com'
+         ),
+        (
+            RouterConfiguration.AUTH_BEARER,
+            'test_key',
+            None,
+            None,
+            RouterConfiguration.CALIPER_BACKEND,
+            'http://test2.com'
+        ),
+        (
+            None,
+            None,
+            None,
+            None,
+            RouterConfiguration.CALIPER_BACKEND,
+            'http://test3.com'
+        ),
+        (RouterConfiguration.AUTH_BASIC,
+         None,
+         'abc',
+         'xyz',
+         RouterConfiguration.XAPI_BACKEND,
+         'http://test1.com'
+         ),
+        (
+            RouterConfiguration.AUTH_BEARER,
+            'test_key',
+            None,
+            None,
+            RouterConfiguration.XAPI_BACKEND,
+            'http://test2.com'
+        ),
+        (
+            None,
+            None,
+            None,
+            None,
+            RouterConfiguration.XAPI_BACKEND,
+            'http://test3.com'
+        ),
+    )
     @patch('event_routing_backends.utils.http_client.requests.post')
     @patch('event_routing_backends.utils.xapi_lrs_client.RemoteLRS')
-    def test_successful_routing_of_event(self, mocked_lrs, mocked_post):
+    @ddt.unpack
+    def test_successful_routing_of_event(
+        self,
+        auth_scheme,
+        auth_key,
+        username,
+        password,
+        backend_name,
+        route_url,
+        mocked_lrs,
+        mocked_post,
+    ):
+        TieredCache.dangerous_clear_all_tiers()
         mocked_oauth_client = MagicMock()
         mocked_api_key_client = MagicMock()
-        route_url = 'http://test3.com'
 
         MOCKED_MAP = {
             'AUTH_HEADERS': HttpClient,
@@ -316,42 +304,61 @@ class TestEventsRouter(TestCase):
             'API_KEY': mocked_api_key_client,
             'XAPI_LRS': LrsClient,
         }
-
         RouterConfigurationFactory.create(
-            backend_name='test_routing',
+            backend_name=backend_name,
             enabled=True,
             route_url=route_url,
-            configurations=ROUTER_CONFIG_FIXTURE
+            auth_scheme=auth_scheme,
+            auth_key=auth_key,
+            username=username,
+            password=password,
+            configurations=ROUTER_CONFIG_FIXTURE[0]
         )
 
-        router = EventsRouter(processors=[], backend_name='test_routing')
+        router = EventsRouter(processors=[], backend_name=backend_name)
 
         with patch.dict('event_routing_backends.tasks.ROUTER_STRATEGY_MAPPING', MOCKED_MAP):
             router.send(self.transformed_event)
 
-        # test the HTTP client
         overridden_event = self.transformed_event.copy()
         overridden_event['new_key'] = 'new_value'
 
-        mocked_post.assert_has_calls([
-            call(
-                url=route_url,
-                json=overridden_event,
-                headers={
-                    'Authorization': 'Bearer test_key'
-                }
-            ),
-        ])
-        # test LRS Client
-        mocked_lrs().save_statement.assert_has_calls([
-            call(self.transformed_event),
-        ])
-
-        # test mocked api key client
-        mocked_api_key_client.assert_has_calls([
-            call(**ROUTER_CONFIG_FIXTURE[3]['host_configurations']),
-            call().send(self.transformed_event)
-        ])
+        if backend_name == RouterConfiguration.XAPI_BACKEND:
+            # test LRS Client
+            mocked_lrs().save_statement.assert_has_calls([
+                call(overridden_event),
+            ])
+        else:
+            # test the HTTP client
+            if auth_scheme == RouterConfiguration.AUTH_BASIC:
+                mocked_post.assert_has_calls([
+                    call(
+                        url=route_url,
+                        json=overridden_event,
+                        headers={
+                        },
+                        auth=(username, password)
+                    ),
+                ])
+            elif auth_scheme == RouterConfiguration.AUTH_BEARER:
+                mocked_post.assert_has_calls([
+                    call(
+                        url=route_url,
+                        json=overridden_event,
+                        headers={
+                            'Authorization': RouterConfiguration.AUTH_BEARER + ' ' + auth_key
+                        }
+                    ),
+                ])
+            else:
+                mocked_post.assert_has_calls([
+                    call(
+                        url=route_url,
+                        json=overridden_event,
+                        headers={
+                        },
+                    ),
+                ])
 
         # test mocked oauth client
         mocked_oauth_client.assert_not_called()
@@ -365,4 +372,14 @@ class TestEventsRouter(TestCase):
                     }
         client = LrsClient(**host_configurations)
         with self.assertRaises(EventNotDispatched):
-            client.send({})
+            client.send(event_name='test', statement_data={})
+
+    def test_unsuccessful_routing_of_event_http(self):
+        host_configurations = {
+                        'url': 'http://test4.com',
+                        'auth_scheme': 'bearer',
+                        'auth_key': 'key',
+                    }
+        client = HttpClient(**host_configurations)
+        with self.assertRaises(EventNotDispatched):
+            client.send(event=self.transformed_event, event_name=self.transformed_event['name'])
